--[[
 - Copyright (c) 2011, 2012 Ryan Vogt <vogt@cs.ualberta.ca>
 -
 - Permission to use, copy, modify, and/or distribute this software for any
 - purpose with or without fee is hereby granted, provided that the above
 - copyright notice and this permission notice appear in all copies.
 -
 - THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 - WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 - MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 - ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 - WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 - ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 - OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
--]]

--[[
 - Use this script to output a large number of hands played by an opponent in
 - Triple Triad, for subsequent statistic analysis.  Start this script after
 - you have challenged them to a game of Triple Triad, and the Play/Quit menu
 - is visible, with the cursor pointing at Play.
 -
 - There appear to be two key memory addresses at play.
 - 0x001A2C6C: A 32-bit counter for how many frames have advanced since the
 -             Triple Triad screen loaded, that forms part of the PRNG state
 -             used to determine the five cards the opponent will play when the
 -             Play menu item is selected.
 - 0x001A2C48: Five bytes containing the five card indices that are played
 -             shortly after Play has been selected.
--]]

handsToDump = 131072;
updateProgress = 100;
filename = "CardDump.txt"

function secondsToTime(seconds)
    local hours = math.floor(seconds / 3600);
    seconds = seconds - hours * 3600;
    local minutes = math.floor(seconds / 60);
    seconds = math.floor(seconds - minutes * 60 + 0.5);
    return string.format("%d:%02d:%02d", hours, minutes, seconds);
end

function outputProgress(startTime, done, total)
    local secondsElapsed = os.time() - startTime;
    if done ~= 0 and done ~= total then
        local remaining = secondsElapsed * total / done - secondsElapsed;
        print(string.format("%d / %d (%.2f%%) -- %s elapsed (ETA: %s)",
                            done, total, done / total * 100,
                            secondsToTime(secondsElapsed),
                            secondsToTime(remaining)));
    else
        print(string.format("%d / %d (%.2f%%) -- %s elapsed",
                            done, total, done / total * 100,
                            secondsToTime(secondsElapsed)));
    end
end

function dumpHands()
    local saveSlot = savestate.create();
    savestate.save(saveSlot);
    local outputFile = assert(io.open(filename, "w"));
    emu.speedmode("maximum");
    local startTime = os.time();
    for onHand = 0,handsToDump-1,1 do
        if onHand % updateProgress == 0 and onHand ~= handsToDump-1 then
            outputProgress(startTime, onHand, handsToDump);
        end
        savestate.load(saveSlot);
        emu.frameadvance();
        savestate.save(saveSlot);
        joypad.set(1, {["x"]=true});
        for i = 0,16,1 do
            emu.frameadvance();
        end
        outputFile:write(string.format("%d %d %d %d %d\n",
                                       memory.readbyte(0x001A2C48),
                                       memory.readbyte(0x001A2C49),
                                       memory.readbyte(0x001A2C4A),
                                       memory.readbyte(0x001A2C4B),
                                       memory.readbyte(0x001A2C4C)));
    end
    outputProgress(startTime, handsToDump, handsToDump);
    outputFile:close();
    emu.speedmode("normal");
end

dumpHands();