/*
 * Copyright (c) 2010, 2012 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.audio;
import triad.backend.*;

/**
 * The <code>OSXSphinx4Helper</code> class is an implementation of the Triple
 * Triad helper program that uses audio output backed by OS X and audio input
 * backed by the Sphinx 4 library.
 */
public class OSXSphinx4Helper extends TriadHelper
{
    /**
     * The command line flag to turn on careful mode.
     */
    private static final String CAREFUL_FLAG = "-careful";

    /**
     * The command line flag to turn on rude mode.
     */
    private static final String RUDE_FLAG = "-rude";

    /**
     * The preferences setting for careful mode.
     */
    private static final String CAREFUL_SETTING = "audio.careful";

    /**
     * The preferences setting for rude mode.
     */
    private static final String RUDE_SETTING = "audio.rude";

    /**
     * The preferences setting for the preferred microphone.
     */
    private static final String MICROPHONE_SETTING = "audio.microphone";

    /**
     * Runs the <code>TriadHelper</code> program using audio as the method of
     * input/output.
     *
     * @param args the command line arguments.
     */
    public static void main(String[] args)
    {
        TriadHelper th = new TriadHelper();
	Preferences pref = th.getPreferences();
	pref.addFlag(OSXSphinx4Helper.CAREFUL_FLAG,
		     OSXSphinx4Helper.CAREFUL_SETTING);
	pref.addFlag(OSXSphinx4Helper.RUDE_FLAG,
		     OSXSphinx4Helper.RUDE_SETTING);
	try {
	    pref.parseCommandLine(args);
	}
	catch (PreferencesException pe) {
	    System.err.println(pe);
	    System.exit(-1);
	}

	boolean careful = pref.getBoolean(OSXSphinx4Helper.CAREFUL_SETTING);
	boolean rude = pref.getBoolean(OSXSphinx4Helper.RUDE_SETTING);
	String microphone =
	    pref.getString(OSXSphinx4Helper.MICROPHONE_SETTING);

	LanguageGenerator language = (rude ?
				      new LanguageRude() :
				      new LanguageFast());
	OutputMethod audioOutput = new OutputOSX();
	InputMethod audioInput = new InputSphinx4(audioOutput, microphone);
	IOMethod io = new IOAudio(audioInput, audioOutput, language, careful);
        th.run(io);
    }
}
