/*
 * Copyright (c) 2012 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.audio;

/**
 * The <code>OutputOSX</code> class represents a method for outputting speech
 * using OS X's underlying say command-line program.
 */
public class OutputOSX extends OutputMethod
{
    /**
     * The program that will output text as speech.
     */
    private static final String SPEECH_PROGRAM = "/usr/bin/say";

    /**
     * Creates a new <code>OutputOSX</code> that will output audio using the
     * underlying OS X say application.
     */
    public OutputOSX()
    {
	super();
    }

    /**
     * Outputs the given message in speech, returning when the audio output is
     * complete.
     *
     * @param message the message to output.
     * @throws AudioException if there is an error outputting the speech.
     */
    protected void outputSpeech(String message)
    {
	Process process;
        String[] cmd = new String[2];
        cmd[0] = OutputOSX.SPEECH_PROGRAM;
        cmd[1] = message;

        try {
            process = Runtime.getRuntime().exec(cmd);
        }
        catch (Exception e) {
            throw new AudioException("Could not execute " + cmd[0]);
        }

	boolean done = false;
	do {
	    try {
		process.waitFor();
		done = true;
	    }
	    catch (InterruptedException iex) {}
	} while (done == false);
    }
}
