/*
 * Copyright (c) 2012 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.backend;
import java.util.*;

/**
 * The <code>BoardFactory</code> class is used to create {@link Board} objects
 * on which games of Triple Triad are played.  A <code>BoardFactory</code> is
 * responsible for creating a board with all of the rules and elemental
 * properties specified to the factory.
 */
public class BoardFactory
{
    /**
     * Creates a new <code>BoardFactory</code> with no rules yet specified.
     */
    public BoardFactory()
    {
    }

    /**
     * Returns a list of the rules that will be used to generate a board.
     *
     * @return a list of the active rules.
     */
    public List<String> getRules()
    {
	List<String> list = new ArrayList<String>();
 	list.add("Open");
	list.add("Trade Rule: One");
	return list;
    }

    /**
     * Returns a new <code>Board</code> that functions with all of the rules
     * specified to the factory.
     *
     * @param handOne the hand of cards that Player One will play.
     * @param handTwo the hand of cards that Player Two will play.
     * @return a new board adhering to the rules of this factory on which the
     * two given hands are in play.
     */
    public Board createBoard(Hand handOne, Hand handTwo)
    {
	/*
	 * Only the Open rule has been implemented to-date.  To implement more
	 * rules, add methods such as setSame(boolean) and setPlus(boolean) to
	 * the BoardFactory class, then have this method return an appropriate
	 * subclass of Board (e.g., BoardComplex could implement many different
	 * rules).
	 */
	return new BoardOpenOnly(handOne, handTwo);
    }
}