/*
 * Copyright (c) 2010, 2012 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.backend;

/**
 * The <code>Player</code> class represents an object that can be asked to
 * decide on a next move.
 */
public abstract class Player
{
    /**
     * The name of the player.
     */
    private String name;

    /**
     * The IO method to be used to communicate with the user.
     */
    protected IOMethod io;

    /**
     * Creates a new <code>Player</code> with the given name.
     *
     * @param name the name of the player.
     */
    public Player(String name, IOMethod io)
    {
	this.name = name;
	this.io = io;
    }

    /**
     * Returns the name of the player.
     *
     * @return the name of the player.
     */
    public String name()
    {
	return this.name;
    }

    /**
     * Returns a <code>String</code> representation of the player, namely its
     * name.
     *
     * @return the name of the player.
     */
    public String toString()
    {
	return this.name;
    }

    /**
     * Return the move that this player wants to make on the given board.
     *
     * @param board the board on which to make the move.
     * @return the move to make.
     */
    public abstract Move getMove(Board board);
}