/*
 * Copyright (c) 2010, 2012, 2013 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.backend;
import java.util.*;

/**
 * The <code>PlayerManual</code> class represents a Triple Triad player that is
 * controlled by user input.
 */
public class PlayerManual extends Player
{
    /**
     * A model to verify against player input, or <code>null</code> if
     * verification is not needed.
     */
    private SearchModel model;

    /**
     * Creates a new <code>PlayerManual</code> with the given name.
     *
     * @param name the name of the player.
     * @param io the IO method used to communicate with the user.
     */
    public PlayerManual(String name, IOMethod io)
    {
        super(name, io);
	this.model = null;
    }

    /**
     * Sets all of the manual inputs to be checked against the given model.
     *
     * @param the model to check against, or <code>null</code> to disable
     * verification.
     */
    public void setVerification(SearchModel model)
    {
	this.model = model;
    }

    /**
     * Return the move that this player wants to make on the given board.
     *
     * @param board the board on which to make the move.
     * @return the move to make.
     */
    public Move getMove(Board board)
    {
	if (this.model != null) {
	    SearchVerifier sv = new SearchVerifier(this.model, board);
	    return this.io.inputManualMove(board, sv);
	}
	else
	    return this.io.inputManualMove(board);
    }
}