/*
 * Copyright (c) 2013 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.backend;
import java.util.*;

/**
 * The <code>SearchAll</code> class models a Triple Triad player that fully
 * explores (with potentially cutting for efficiency purposes) the entire
 * search tree, thus playing perfectly.
 */
public class SearchAll implements SearchModel
{
    /**
     * Returns an iteration over all of the possible moves.
     *
     * @param board the situation to which to apply the opponent model.
     * @return an iteration of all possible moves.
     */
    public Iterator<SearchBranch> model(Board board)
    {
	List<SearchBranch> list = new ArrayList<SearchBranch>();
	for (int onCard = Board.NUM_SIDE-1; onCard >= 0; onCard--) {
	    if (board.isCardOnSide(onCard) == false)
		continue;
	    for (int onSpace = 0; onSpace < Board.NUM_SQUARES; onSpace++) {
		if (board.isSquareEmpty(onSpace) == false)
		    continue;
		list.add(new SearchBranch(onCard, onSpace));
	    }
	}
	return list.listIterator();
    }
}
