/*
 * Copyright (c) 2013 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.backend;

/**
 * The <code>SearchBranch</code> class is responsible for representing a single
 * move in an alpha-beta search tree.  It is similar to, but less flexible
 * than, the {@link Move} class.  The use of the <code>SearchBranch</code> is
 * discouraged outside of the context of alpha-beta searches, where its
 * efficiency is important, due it its inherently ambiguous constructor and
 * limited expressiveness.
 */
public class SearchBranch
{
    /**
     * The card index from the side-hand of the move.
     */
    private int card;

    /**
     * The space index onto the board of the move.
     */
    private int space;

    /**
     * Creates a new <code>SearchBranch</code> with the given card and space
     * indices.
     *
     * @param card the index of the card played from the side-hand.
     * @param space the board index of the space into which the card is played.
     */
    public SearchBranch(int card, int space)
    {
	this.card = card;
	this.space = space;
    }

    /**
     * Returns the index of the card played from the side-hand.
     *
     * @return the index of the card.
     */
    public int getCard()
    {
	return this.card;
    }

    /**
     * Returns the index of the space on the board into which the card is
     * played.
     *
     * @return the index of the space on the board.
     */
    public int getSpace()
    {
	return this.space;
    }
}