/*
 * Copyright (c) 2010, 2012 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package triad.console;
import triad.backend.*;

/**
 * The <code>ConsoleHelper</code> class is an implementation of the Triple
 * Triad helper program that uses console input and output.
 */
public class ConsoleHelper extends TriadHelper
{
    /**
     * The command line flag to turn on verbose mode.
     */
    private static final String VERBOSE_FLAG = "-verbose";

    /**
     * The preferences setting for verbose mode.
     */
    private static final String VERBOSE_SETTING = "console.verbose";

    /**
     * Runs the <code>TriadHelper</code> program using the console as the
     * method of input/output.
     *
     * @param args the command line arguments.
     */
    public static void main(String[] args)
    {
        TriadHelper th = new TriadHelper();
	Preferences pref = th.getPreferences();
	pref.addFlag(ConsoleHelper.VERBOSE_FLAG,
		     ConsoleHelper.VERBOSE_SETTING);
	try {
	    pref.parseCommandLine(args);
	}
	catch (PreferencesException pe) {
	    System.err.println(pe);
	    System.exit(-1);
	}

	boolean verbose = pref.getBoolean(ConsoleHelper.VERBOSE_SETTING);
	IOMethod io = new IOConsole(verbose);
        th.run(io);
    }
}
